.. csboilerplate documentation master file, created by
   sphinx-quickstart on Wed Jun 13 12:12:44 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to csboilerplate's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
